<?php

/**
 * Class for generating flexible content in WP
 */
class FlexibleContent {
	function __construct( $id ) {
		//id wpisu
		$this->id = $id;
	}

	/**
	 * genereting content from ACF Flexible content
	 */
	function get_content() {
		// tpls are stored here
		$tpl_core = 'templates/flex/';
		if ( have_rows( 'content', $this->id ) ) {
			$i = 0;
			// loop through the rows of data
			while ( have_rows( 'content', $this->id ) ) {
				the_row();

				//clean array
				$tpl_args = [];

				$tpl_args['i'] = $i;

				if ( 'one_column' == get_row_layout() ) {
					// One column wrapper
					$tpl_args['full_viewport_width'] = get_sub_field( 'full_viewport_width' );
					$tpl_args['viewport_class'] = '';
					$thumb_size = 'flex_100';
					if ( $tpl_args['full_viewport_width'] ) {
						$tpl_args['viewport_class'] = 'expanded collapse';
						$thumb_size = 'full_viewport';
					}

					$tpl_args['type'] = get_sub_field( 'type' );
					$tpl_args['text'] = get_sub_field( 'text' );
					$tpl_args['image'] = wp_get_attachment_image_src( get_sub_field( 'image' ), 'flex_100' )[0];
					$tpl_args['image_description'] = get_sub_field( 'image_description' );
					$tpl_args['wrapper_class'] = get_sub_field( 'wrapper_class' );
					$tpl_args['wrapper_id'] = get_sub_field( 'wrapper_id' );
					$tpl_args['img_wrapper_class'] = 'text-center';
					$tpl_args['img_class'] = '';

					if( get_sub_field( 'type' ) == 'image' ) {
						$tpl_args['wrapper_class'] .= ' wow fadeInUp text-left large-text-left';
					}

					if( get_sub_field( 'no_img_shadow' ) ) {
								$tpl_args['img_class'] = 'noshadow';
					}

					$wrapper = 'wrapper-one-column';

				} elseif ( 'two_columns' == get_row_layout() ) {
					//Two columns wrapper
					$tpl_args['left']['type'] = get_sub_field( 'left_column_type' );
					$tpl_args['left']['text'] = get_sub_field( 'left_text' );
					$tpl_args['left']['image'] = wp_get_attachment_image_src( get_sub_field( 'left_image' ), 'flex_50' )[0];
					$tpl_args['left']['image_description'] = get_sub_field( 'left_image_description' );
					$tpl_args['left']['img_class'] = '';
					$tpl_args['left']['img_wrapper_class'] = '';
					$tpl_args['left']['wrapper_class'] = '';

					if( get_sub_field( 'left_column_type' ) == 'image' ) {
						$tpl_args['left']['wrapper_class'] = 'wow fadeInUp text-left large-text-left';
					}

					if( get_sub_field( 'left_no_img_shadow' ) ) {
						$tpl_args['left']['img_class'] = 'noshadow';
					}

					$tpl_args['right']['type'] = get_sub_field( 'right_column_type' );
					$tpl_args['right']['text'] = get_sub_field( 'right_text' );
					$tpl_args['right']['image'] = wp_get_attachment_image_src( get_sub_field( 'right_image' ), 'flex_50' )[0];
					$tpl_args['right']['image_description'] = get_sub_field( 'right_image_description' );
					$tpl_args['right']['img_class'] = '';
					$tpl_args['right']['img_wrapper_class'] = '';
					$tpl_args['right']['wrapper_class'] = '';

					if( get_sub_field( 'right_column_type' ) == 'image' ) {
						$tpl_args['right']['wrapper_class'] = 'wow fadeInUp text-left large-text-left';
					}

					if( get_sub_field( 'right_no_img_shadow' ) ) {
						$tpl_args['right']['img_class'] = 'noshadow';
					}

					$tpl_args['wrapper_class'] = get_sub_field( 'wrapper_class' );
					$tpl_args['wrapper_id'] = get_sub_field( 'wrapper_id' );

					$wrapper = 'wrapper-two-columns';

				} elseif ( 'grid' == get_row_layout() ) {
					// Wrapper for logo grid
					$tpl_args['entries'] = get_sub_field( 'entries' );
					$tpl_args['wrapper_id'] = get_sub_field( 'wrapper_id' );

					$grid_i = 1;
					foreach ( $tpl_args['entries'] as $key => $val ) {
							$tpl_args['entries'][$key]['i'] = $i;
							$tpl_args['entries'][$key]['end'] = '';

							if ( get_sub_field( 'type' ) != 'mosaic') {
								$tpl_args['entries'][$key]['columns'] = 12 / get_sub_field( 'columns' );
							}

							// class end for last logo
 							if ( $grid_i >= count( $tpl_args['entries'] ) ) {
								$tpl_args['entries'][$key]['end'] = 'end';
							}

							// different thumbnail size based on columns number
							if ( get_sub_field( 'type' ) == 'logo') {
								if ( get_sub_field( 'columns' ) == '2' ) {
									$thumb_size = 'flex_50';
								} elseif( get_sub_field( 'columns' ) == '3' ) {
									$thumb_size = 'flex_33';
								} else {
									$thumb_size = 'flex_25';
								}
							} else {
								$thumb_size = 'square';
							}

							$tpl_args['entries'][$key]['image'] = wp_get_attachment_image_src( $val['image'], $thumb_size )[0];
							$tpl_args['entries'][$key]['width'] = $val['width'];


							$grid_i++;
					}

					if ( get_sub_field( 'type' ) == 'logo' ) {
						$tpl_args['entry_type'] = 'block-logo-entry';
						$tpl_args['grid_class']  = 'membership-list';
					} elseif ( get_sub_field( 'type' ) == 'post' ) {
						$tpl_args['entry_type'] = 'block-post-entry';
						$tpl_args['grid_class']  = '';
					} elseif ( get_sub_field( 'type' ) == 'mosaic' ) {
						$tpl_args['entry_type'] = 'block-mosaic-entry';
						$tpl_args['grid_class']  = 'collapse';
					}

					$tpl_args['columns'] = get_sub_field( 'columns' );
					$wrapper = 'wrapper-grid';
				}

				set_query_var( 'tpl_args', $tpl_args );
				get_template_part( $tpl_core . $wrapper );

				unset( $tpl_args );
				$i++;
			}
		}
	}
	/**
	 * Storing content as variable
	 * return string	html code
	 */
	function convert_to_var() {
		ob_start();
		self::get_content();
		$output = ob_get_clean();

		return $output;
	}

	/**
	 * saving post content if post type is page
	 * if you'll need to save pure post_content without Flexible Content add if()
	 */
	function content_on_save() {
		if ( ! wp_is_post_revision( $this->id ) ) {
			// unhook this function so it doesn't loop infinitely
			remove_action( 'acf/save_post', [ $this, 'content_on_save' ], 20 );
		}

		if ( 'page' == get_post_type( $this->id ) && $this->id != 4  ) {
			$my_post['ID'] =$content = $_POST['post_content'];
			$title = $_POST['post_title'];
			
			$my_post['ID'] = $this->id;
			$my_post['post_content'] = $content;
			$test = wp_update_post( $my_post, true );
		}
		if ( 'page' == get_post_type( $this->id ) && $this->id == 4  ) {
			//$content = self::convert_to_var();
			$my_post['ID'] = $this->id;
			$my_post['post_content'] = self::get_content();

			$test = wp_update_post( $my_post, true );
		}
		/*if ( $this->id == 59620  ) {
			$my_post['ID'] =$content = $_POST['post_content'];
			$title = $_POST['post_title'];
			
			$my_post['ID'] = $this->id;
			$my_post['post_content'] = $content;
			$test = wp_update_post( $my_post, true );
		}*/

		
		if ( 'doculibrary' == get_post_type( $this->id ) ) {
			$terms=array();
			$content = $_POST['post_content'];
			$title = $_POST['post_title'];
			
			$my_post['ID'] = $this->id;
			$my_post['post_content'] = $content;
			$test = wp_update_post( $my_post, true );
			$terms  = wp_get_object_terms( $this->id, 'dl_yearp', $args );
			
			if(!empty($terms)){
				$names  = wp_list_pluck( $terms, 'name' );
				update_post_meta(  $this->id,'year_s',$names[0] );}
			//new custom field to update
			update_post_meta(  $this->id,'title_s',$title );
			update_post_meta( $this->id,'content_s', $content);
		}
		
		
		
		
	}
}
